package com.sun.jmx.snmp.agent;

import java.util.Enumeration;
import com.sun.jmx.snmp.SnmpEngine;
import com.sun.jmx.snmp.SnmpVarBind;
import java.util.Vector;
import com.sun.jmx.snmp.SnmpPdu;
import javax.management.MBeanException;
import javax.management.ReflectionException;
import javax.management.ServiceNotFoundException;
import javax.management.InstanceNotFoundException;
import com.sun.jmx.snmp.SnmpOid;
import com.sun.jmx.snmp.SnmpStatusException;
import javax.management.ObjectName;
import javax.management.MBeanServer;
import java.io.Serializable;
import javax.management.MBeanRegistration;

public abstract class SnmpMibAgent implements SnmpMibAgentMBean, MBeanRegistration, Serializable
{
    protected String mibName;
    protected MBeanServer server;
    private ObjectName adaptorName;
    private transient SnmpMibHandler adaptor;
    
    public SnmpMibAgent() {
    }
    
    public abstract void init() throws IllegalAccessException;
    
    @Override
    public abstract ObjectName preRegister(MBeanServer p0, ObjectName p1) throws Exception;
    
    @Override
    public void postRegister(Boolean b) {
    }
    
    @Override
    public void preDeregister() throws Exception {
    }
    
    @Override
    public void postDeregister() {
    }
    
    @Override
    public abstract void get(SnmpMibRequest p0) throws SnmpStatusException;
    
    @Override
    public abstract void getNext(SnmpMibRequest p0) throws SnmpStatusException;
    
    @Override
    public abstract void getBulk(SnmpMibRequest p0, int p1, int p2) throws SnmpStatusException;
    
    @Override
    public abstract void set(SnmpMibRequest p0) throws SnmpStatusException;
    
    @Override
    public abstract void check(SnmpMibRequest p0) throws SnmpStatusException;
    
    public abstract long[] getRootOid();
    
    @Override
    public MBeanServer getMBeanServer() {
        return this.server;
    }
    
    @Override
    public SnmpMibHandler getSnmpAdaptor() {
        return this.adaptor;
    }
    
    @Override
    public void setSnmpAdaptor(SnmpMibHandler adaptor) {
        if (this.adaptor != null) {
            this.adaptor.removeMib(this);
        }
        this.adaptor = adaptor;
        if (this.adaptor != null) {
            this.adaptor.addMib(this);
        }
    }
    
    @Override
    public void setSnmpAdaptor(SnmpMibHandler adaptor, SnmpOid[] array) {
        if (this.adaptor != null) {
            this.adaptor.removeMib(this);
        }
        this.adaptor = adaptor;
        if (this.adaptor != null) {
            this.adaptor.addMib(this, array);
        }
    }
    
    @Override
    public void setSnmpAdaptor(SnmpMibHandler adaptor, String s) {
        if (this.adaptor != null) {
            this.adaptor.removeMib(this, s);
        }
        this.adaptor = adaptor;
        if (this.adaptor != null) {
            this.adaptor.addMib(this, s);
        }
    }
    
    @Override
    public void setSnmpAdaptor(SnmpMibHandler adaptor, String s, SnmpOid[] array) {
        if (this.adaptor != null) {
            this.adaptor.removeMib(this, s);
        }
        this.adaptor = adaptor;
        if (this.adaptor != null) {
            this.adaptor.addMib(this, s, array);
        }
    }
    
    @Override
    public ObjectName getSnmpAdaptorName() {
        return this.adaptorName;
    }
    
    @Override
    public void setSnmpAdaptorName(ObjectName adaptorName) throws InstanceNotFoundException, ServiceNotFoundException {
        if (this.server == null) {
            throw new ServiceNotFoundException(this.mibName + " is not registered in the MBean server");
        }
        if (this.adaptor != null) {
            this.adaptor.removeMib(this);
        }
        Object[] array = { this };
        String[] array2 = { "com.sun.jmx.snmp.agent.SnmpMibAgent" };
        try {
            this.adaptor = (SnmpMibHandler)(SnmpMibHandler)this.server.invoke(adaptorName, "addMib", array, array2);
        }
        catch (InstanceNotFoundException ex) {
            throw new InstanceNotFoundException(adaptorName.toString());
        }
        catch (ReflectionException ex2) {
            throw new ServiceNotFoundException(adaptorName.toString());
        }
        catch (MBeanException ex3) {}
        this.adaptorName = adaptorName;
        return;
    }
    
    @Override
    public void setSnmpAdaptorName(ObjectName adaptorName, SnmpOid[] array) throws InstanceNotFoundException, ServiceNotFoundException {
        if (this.server == null) {
            throw new ServiceNotFoundException(this.mibName + " is not registered in the MBean server");
        }
        if (this.adaptor != null) {
            this.adaptor.removeMib(this);
        }
        Object[] array2 = { this, array };
        String[] array3 = { "com.sun.jmx.snmp.agent.SnmpMibAgent", array.getClass().getName() };
        try {
            this.adaptor = (SnmpMibHandler)(SnmpMibHandler)this.server.invoke(adaptorName, "addMib", array2, array3);
        }
        catch (InstanceNotFoundException ex) {
            throw new InstanceNotFoundException(adaptorName.toString());
        }
        catch (ReflectionException ex2) {
            throw new ServiceNotFoundException(adaptorName.toString());
        }
        catch (MBeanException ex3) {}
        this.adaptorName = adaptorName;
        return;
    }
    
    @Override
    public void setSnmpAdaptorName(ObjectName adaptorName, String s) throws InstanceNotFoundException, ServiceNotFoundException {
        if (this.server == null) {
            throw new ServiceNotFoundException(this.mibName + " is not registered in the MBean server");
        }
        if (this.adaptor != null) {
            this.adaptor.removeMib(this, s);
        }
        Object[] array = { this, s };
        String[] array2 = { "com.sun.jmx.snmp.agent.SnmpMibAgent", "java.lang.String" };
        try {
            this.adaptor = (SnmpMibHandler)(SnmpMibHandler)this.server.invoke(adaptorName, "addMib", array, array2);
        }
        catch (InstanceNotFoundException ex) {
            throw new InstanceNotFoundException(adaptorName.toString());
        }
        catch (ReflectionException ex2) {
            throw new ServiceNotFoundException(adaptorName.toString());
        }
        catch (MBeanException ex3) {}
        this.adaptorName = adaptorName;
        return;
    }
    
    @Override
    public void setSnmpAdaptorName(ObjectName adaptorName, String s, SnmpOid[] array) throws InstanceNotFoundException, ServiceNotFoundException {
        if (this.server == null) {
            throw new ServiceNotFoundException(this.mibName + " is not registered in the MBean server");
        }
        if (this.adaptor != null) {
            this.adaptor.removeMib(this, s);
        }
        Object[] array2 = { this, s, array };
        String[] array3 = { "com.sun.jmx.snmp.agent.SnmpMibAgent", "java.lang.String", array.getClass().getName() };
        try {
            this.adaptor = (SnmpMibHandler)(SnmpMibHandler)this.server.invoke(adaptorName, "addMib", array2, array3);
        }
        catch (InstanceNotFoundException ex) {
            throw new InstanceNotFoundException(adaptorName.toString());
        }
        catch (ReflectionException ex2) {
            throw new ServiceNotFoundException(adaptorName.toString());
        }
        catch (MBeanException ex3) {}
        this.adaptorName = adaptorName;
        return;
    }
    
    @Override
    public boolean getBindingState() {
        return this.adaptor != null;
    }
    
    @Override
    public String getMibName() {
        return this.mibName;
    }
    
    public static SnmpMibRequest newMibRequest(SnmpPdu snmpPdu, Vector<SnmpVarBind> vector, int n, Object o) {
        return new SnmpMibRequestImpl(null, snmpPdu, vector, n, o, null, 0, getSecurityModel(n), null, null);
    }
    
    public static SnmpMibRequest newMibRequest(SnmpEngine snmpEngine, SnmpPdu snmpPdu, Vector<SnmpVarBind> vector, int n, Object o, String s, int n2, int n3, byte[] array, byte[] array2) {
        return new SnmpMibRequestImpl(snmpEngine, snmpPdu, vector, n, o, s, n2, n3, array, array2);
    }
    
    void getBulkWithGetNext(SnmpMibRequest snmpMibRequest, int a, int a2) throws SnmpStatusException {
        Vector<SnmpVarBind> subList = snmpMibRequest.getSubList();
        int size = subList.size();
        int max = Math.max(Math.min(a, size), 0);
        int max2 = Math.max(a2, 0);
        if (size != 0) {
            this.getNext(snmpMibRequest);
            Vector<SnmpVarBind> split = this.splitFrom(subList, max);
            SnmpMibRequestImpl snmpMibRequestImpl = new SnmpMibRequestImpl(snmpMibRequest.getEngine(), snmpMibRequest.getPdu(), split, 1, snmpMibRequest.getUserData(), snmpMibRequest.getPrincipal(), snmpMibRequest.getSecurityLevel(), snmpMibRequest.getSecurityModel(), snmpMibRequest.getContextName(), snmpMibRequest.getAccessContextName());
            for (int i = 2; i <= max2; ++i) {
                this.getNext(snmpMibRequestImpl);
                this.concatVector(snmpMibRequest, split);
            }
        }
    }
    
    private Vector<SnmpVarBind> splitFrom(Vector<SnmpVarBind> vector, int n) {
        Vector<SnmpVarBind> vector2 = new Vector(vector.size() - n);
        for (Enumeration elements = vector.elements(); elements.hasMoreElements(); --n) {
            SnmpVarBind snmpVarBind = (SnmpVarBind)elements.nextElement();
            if (n <= 0) {
                vector2.addElement(new SnmpVarBind(snmpVarBind.oid, snmpVarBind.value));
            }
        }
        return vector2;
    }
    
    private void concatVector(SnmpMibRequest snmpMibRequest, Vector<SnmpVarBind> vector) {
        Enumeration<Object> elements = vector.elements();
        while (elements.hasMoreElements()) {
            SnmpVarBind snmpVarBind = (SnmpVarBind)elements.nextElement();
            snmpMibRequest.addVarBind(new SnmpVarBind(snmpVarBind.oid, snmpVarBind.value));
        }
    }
    
    private static int getSecurityModel(int n) {
        switch (n) {
            case 0: {
                return 1;
            }
            default: {
                return 2;
            }
        }
    }
}
